from plone.app.contenttypes.browser.collection import CollectionView
from plone.app.contenttypes.browser.folder import FolderView


class FolderGridListing(FolderView):
    pass


class CollectionGridListing(CollectionView):
    pass
